#
# spec file for package findutils
#
# Copyright (c) 2022-2023 ZhuningOS
#


Name:           findutils
Version:        4.8.0
Release:        1.20
Summary:        The GNU versions of find utilities (find and xargs)
License:        GPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://www.gnu.org/software/findutils/
# Upstream development:
# cgit-URL:	https://git.savannah.gnu.org/cgit/findutils.git/
# Git-Clone:	git://git.sv.gnu.org/findutils
# For upgrading the upstream version, increase the version number (above),
# then remove the old tarball and signature files and let OSC download
# those files of the new version:
#    osc rm findutils-*.tar.xz findutils-*.tar.xz.sig
#    osc service localrun download_files
#    osc addremove
# Then adjust the downstream patches (using quilt).
# Finally, add a changelog entry and commit:
#    osc vc
#    osc ci
Source0:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        https://savannah.gnu.org/project/release-gpgkeys.php?group=%{name}&download=1&file=./%{name}.keyring
# adds a new option -xautofs to find to not descend into directories on autofs file systems
Patch0:         findutils-xautofs.patch
# BuildRequire dejagnu for 'runtest' to execute all tests.
BuildRequires:  dejagnu
BuildRequires:  makeinfo
Provides:       find = %{version}
Obsoletes:      find < %{version}
%if 0%{?suse_version} > 1100
BuildRequires:  libselinux-devel
%endif

%description
The findutils package contains programs which will help you locate
files on your system.  The find utility searches through a hierarchy
of directories looking for files which match a certain set of criteria
(such as a file name pattern).  The xargs utility builds and executes
command lines from standard input arguments (usually lists of file
names generated by the find command).

You should install findutils because it includes tools that are very
useful for finding things on your system.

%lang_package

%prep
%setup -q
%patch0

%build
%if 0%{?qemu_user_space_build}
# this is a workaround for a qemu-user bug, we hit. A qemu patch is being discussed, but for now ...
export DEFAULT_ARG_SIZE="(31u * 1024u)"
%endif
%configure \
  --libexecdir=%{_libdir}/find \
  --localstatedir=%{_localstatedir}/lib

%make_build

%check
%make_build check \
  || { grep . */test-suite.log; exit 1; }

%install
%make_install

rm -f %{buildroot}%{_infodir}/find-maint*
%find_lang %{name}
%if !0%{?usrmerged}
mkdir -p %{buildroot}/bin
ln -sf %{_bindir}/find %{buildroot}/bin
%endif

rm %{buildroot}%{_bindir}/locate
rm %{buildroot}%{_bindir}/updatedb
rm -r %{buildroot}%{_libdir}/find
rm %{buildroot}%{_mandir}/man1/locate.1*
rm %{buildroot}%{_mandir}/man1/updatedb.1*
rm %{buildroot}%{_mandir}/man5/locatedb.5*

%files
%license COPYING
%doc AUTHORS NEWS README THANKS TODO
%if !0%{?usrmerged}
/bin/find
%endif
%{_bindir}/find
%{_bindir}/xargs
%{_infodir}/find.info*.gz
%{_mandir}/man1/find.1%{?ext_man}
%{_mandir}/man1/xargs.1%{?ext_man}

%files lang -f %{name}.lang
%license COPYING

%changelog
